Installation instructions — BioSimulators-COPASI 0.1.33 documentation

# Installation instructions

BioSimulators-COPASI is available as a command-line program and as a command-line program encapsulated into a Docker image.

## Command-line program

After installing Python (>= 3.7) and pip, run the following command to install BioSimulators-COPASI:

    pip install biosimulators-copasi

## Docker image with a command-line entrypoint

After installing Docker, run the following command to install the Docker image for BioSimulators-COPASI:

    docker pull ghcr.io/biosimulators/copasi